function hinfo = h_open(fname)
% hinfo = h_open(fname)
%
% Open HRTF dataset, returns hinfo handle. See description of hinfo
% in h_new().
%
% Copyright (c) 2006 Wave Arts, Inc.
% Written by Bill Gardner
%

use_text_header = 1;

global h_cur_id;
if (~exist('h_cur_id'))
	h_cur_id = 0;
elseif isempty(h_cur_id)
   % for compatibility with newer matlab versions that auto-initialize
   % non-existant globals to the empty matrix.
   h_cur_id = 0;
end

%
% Create full pathname
%
path = h_path(fname);

%
% Read MATLAB variable file containing auxiliary information in
% hinfo, itds, and elevs. When we load this, it will overwrite the
% local copy of these variables.
%
if exist(path) == 2
	if use_text_header
		[info,itds,elevs] = h_load_hdr(fname);
	else
		info = 0;
		eval(sprintf('load %s.mat',path));
	end
	hinfo = info;
	hinfo(1) = h_cur_id;
else
	error(sprintf('cannot find %s',path));
end

%
% Declare globals
%
eval(sprintf('global h_fname%d;',hinfo(1)));
eval(sprintf('global h_itds%d;',hinfo(1)));
eval(sprintf('global h_elevs%d;',hinfo(1)));

%
% Set up globals
%
eval(sprintf('h_fname%d = fname;',hinfo(1)));
eval(sprintf('h_itds%d = itds;',hinfo(1)));
eval(sprintf('h_elevs%d = elevs;',hinfo(1)));

h_cur_id = h_cur_id + 1;
